/****************************************************************************
**
** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Lesser General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
**
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Lesser General Public License for more details.
**
** You should have received a copy of the GNU Lesser General Public
** License along with this library; if not, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA 02111-1307, USA.
**
****************************************************************************/
/*
 * ChangeLog -  
 *				July 05, 2012
 * 				1. Added methods to store RTP parameters (added in TM specs v1.0.1)
 *              2. The parameters include IPL value, MPL value, required payloadType.
 */

#include "QTmClientProfile.h"
#include <qdebug.h>
/*!
  \class QTmClientProfile

  \brief The QTmClientProfile class provides access to the encapsulated client profile data, utilized by the TmClientProfile:1 UPnP service.

  The Client Profile data contains preferences which can be set by the Terminal Mode Client such as client's identifying information, icon preferences,
  Bluetooth settings and driver distraction rules.

  This class represents the A_ARG_TYPE_ClientProfile variable of TmClientProfile:1 UPnP service.
*/

/*!
  Class constructor. Arguments \a clientId (Terminal Mode Client Identifier) and \a parent.
 */
QTmClientProfile::QTmClientProfile(QString clientId, QObject *parent) :
        m_clientId(clientId),
        m_startBTConnection(false) {
    Q_UNUSED(parent)
}

QTmClientProfile::QTmClientProfile()
{
}

/*!
  Class destructor.
 */
QTmClientProfile::~QTmClientProfile()
{

}

/*!
  Get the ClientId of Terminal Mode client.
  The function will return a QString.
 */
QString QTmClientProfile::clientId()
{
    return m_clientId;
}

void QTmClientProfile::setClientId(QString clientId)
{
    m_clientId = clientId;
}

/*!
  Set the Client Name of Terminal Mode client
  to \a clientName.
 */
void QTmClientProfile::setClientName(QString clientName)
{
    m_clientName = clientName;
}

/*!
  Get the Client Name of Terminal Mode client.
  The function will return a QString.
 */
QString QTmClientProfile::clientName()
{
    return m_clientName;
}

/*!
  Set the Manufacturer Name of Terminal Mode client
  to \a manufacturerName.
 */
void QTmClientProfile::setManufacturerName(QString manufacturerName)
{
    m_manufacturerName = manufacturerName;
}

/*!
  Get the Manufacturer Name of Terminal Mode client.
  The function will return a QString.
 */
QString QTmClientProfile::manufacturerName()
{
    return m_manufacturerName;
}

/*!
  Set the Model Name of Terminal Mode client
  to \a modelName.
 */
void QTmClientProfile::setModelName(QString modelName)
{
    m_modelName = modelName;
}

/*!
  Get the Model Name of Terminal Mode client.
  The function will return a QString.
 */
QString QTmClientProfile::modelName()
{
    return m_modelName;
}

/*!
  Set the Model Number of Terminal Mode client
  to \a modelNumber.
 */
void QTmClientProfile::setModelNumber(QString modelNumber)
{
    m_modelNumber = modelNumber;
}

/*!
  Get the Model Number of Terminal Mode client.
  The function will return a QString.
 */
QString QTmClientProfile::modelNumber()
{
    return m_modelNumber;
}

/*!
  Set the preferred Icon Mimetype of Terminal Mode client
  to \a mimeType.
 */
void QTmClientProfile::setIconMimeType(QString mimeType)
{
    m_iconMimeType = mimeType;
}

/*!
  Get the preferred Icon Mimetype of Terminal Mode client.
  The function will return a QString.
 */
QString QTmClientProfile::iconMimeType()
{
    return m_iconMimeType;
}

/*!
  Set the preferred Icon Width of Terminal Mode client
  to \a iconWidth.
 */
void QTmClientProfile::setIconWidth(int iconWidth)
{
    m_iconWidth = iconWidth;
}

/*!
  Get the preferred Icon Width of Terminal Mode client.
  The function will return an int.
 */
int QTmClientProfile::iconWidth()
{
    return m_iconWidth;
}

/*!
  Set the preferred Icon Height of Terminal Mode client
  to \a iconHeight.
 */
void QTmClientProfile::setIconHeight(int iconHeight)
{
    m_iconHeight = iconHeight;
}

/*!
  Get the preferred Icon Height of Terminal Mode client.
  The function will return an int.
 */
int QTmClientProfile::iconHeight()
{
    return m_iconHeight;
}

/*!
  Set the preferred Icon Depth of Terminal Mode client
  to \a iconDepth.
 */
void QTmClientProfile::setIconDepth(int iconDepth)
{
    m_iconDepth = iconDepth;
}

/*!
  Get the preferred Icon Depth of Terminal Mode client.
  The function will return an int.
 */
int QTmClientProfile::iconDepth()
{
    return m_iconDepth;
}

/*!
  Set the Bluetooth Device Address of Terminal Mode client
  to \a bdAddr.
 */
void QTmClientProfile::setBdAddr(QString bdAddr)
{
    m_bdAddr = bdAddr;
}

/*!
  Get the Bluetooth Device Address of Terminal Mode client.
  The function will return a QString.
 */
QString QTmClientProfile::bdAddr()
{
    return m_bdAddr;
}

/*!
  Set whether Terminal Mode client will initiate Bluetooth connections
  to \a startBTConnection (true or false).
 */
void QTmClientProfile::setStartBTConnection(bool startBTConnection)
{
    m_startBTConnection = startBTConnection;
}

/*!
  Get whether Terminal Mode client will initiate Bluetooth connections.
  The function will return a boolean value.
 */
bool QTmClientProfile::startBTConnection()
{
    return m_startBTConnection;
}

/*!
  Set the Driver Distraction Rules specified by the Terminal Mode client
  to those specified in \a clientRules.
 */
void QTmClientProfile::setClientRules(QTmClientRules clientRules)
{
    m_clientRules = clientRules;
}

/*!
  Get the Driver Distraction Rules specified by the Terminal Mode client.
  The function will return a QTmClientRules object.
 */
QTmClientRules QTmClientProfile::clientRules()
{
    return m_clientRules;
}


/*!
  Set the IPL parameter of Terminal Mode client
  to .
 */
void QTmClientProfile:: setrtpipl(int rtpipl)
{
    qDebug("RTP set ipl value %d\n",rtpipl);
    m_rtpipl = rtpipl;
}

/*!
  Get the IPL parameter of Terminal Mode client.
  The function will return a int.
 */
int QTmClientProfile::rtpipl()
{
     qDebug("RTP ipl value returned %d\n",m_rtpipl);
    return m_rtpipl;
}
/*!
  Set the MPL parameter of Terminal Mode client
  to \a .
 */
void QTmClientProfile::setrtpmpl(int rtpmpl)
{
   qDebug("RTP set mpl value %d\n",rtpmpl);
   m_rtpmpl = rtpmpl;
}

/*!
  Get the MPL parameter of Terminal Mode client.
  The function will return a int.
 */
int QTmClientProfile::rtpmpl()
{
    qDebug("RTP mpl value returned %d\n",m_rtpmpl);
    return m_rtpmpl;
}
/*!
  Set the Payload parameter of Terminal Mode client
  to \a .
 */
void QTmClientProfile::setrtppayload(int rtppayload)
{
    qDebug("RTP set payload value %d\n",rtppayload);
    m_rtppayload = rtppayload;
}

/*!
  Get the Payload parameter of Terminal Mode client.
  The function will return a int.
 */
int QTmClientProfile::rtppayload()
{
    qDebug("RTP mpl value returned %d\n",m_rtppayload);
    return m_rtppayload;
}




/*!
  Check whether this TmClientProfile object is empty or not.
  The function will return a boolean.
 */
bool QTmClientProfile::isNull()
{
    if(!clientId().compare("null", Qt::CaseInsensitive))
        return true;
    else
        return false;
}

bool QTmClientProfile::equals(QTmClientProfile* clientProfile)
{
    bool equal = false;
#ifdef QT_CODE_DEBUG

    qDebug()<<"Local Client Id :: " <<  clientProfile->clientId() << "";
    qDebug()<<"clientProfile->clientId().compare(m_clientId) :" <<(clientProfile->clientId().compare(m_clientId));
    qDebug()<<"Current Client Id ********** "<<m_clientId;
    qDebug()<<"(clientProfile->clientName().compare(m_clientName))"<<(clientProfile->clientName().compare(m_clientName));
    qDebug()<<"(clientProfile->manufacturerName().compare(m_manufacturerName))"<<(clientProfile->manufacturerName().compare(m_manufacturerName));
    qDebug()<<"(clientProfile->modelName().compare(m_modelName))"<< (clientProfile->modelName().compare(m_modelName));
    qDebug()<<"(clientProfile->modelNumber().compare(m_modelNumber))"<< (clientProfile->modelNumber().compare(m_modelNumber));
    qDebug()<<"(clientProfile->iconMimeType().compare(m_iconMimeType))"<<(clientProfile->iconMimeType().compare(m_iconMimeType));
    qDebug()<<"(clientProfile->iconWidth() != m_iconWidth)"<<(clientProfile->iconWidth() != m_iconWidth);
    qDebug()<<"(clientProfile->iconHeight() != m_iconHeight)"<<(clientProfile->iconHeight() != m_iconHeight);
    qDebug()<<"(clientProfile->iconDepth() != m_iconDepth)"<<(clientProfile->iconDepth() != m_iconDepth);
    qDebug()<<"(clientProfile->bdAddr().compare(m_bdAddr))" << (clientProfile->bdAddr().compare(m_bdAddr));
    qDebug()<<"(clientProfile->startBTConnection() != m_startBTConnection)"<<(clientProfile->startBTConnection() != m_startBTConnection);
    qDebug()<< "(clientProfile->clientRules().getRule(0).compare(true)" << (clientProfile->clientRules().getRule(0).compare("true"));
    qDebug()<< "(clientProfile->clientRules().getRule(1).compare(test)" << (clientProfile->clientRules().getRule(1).compare("test"));
#endif
    if((clientProfile->clientId().compare(m_clientId))
        || (clientProfile->clientName().compare(m_clientName))
        || (clientProfile->manufacturerName().compare(m_manufacturerName))
        || (clientProfile->modelName().compare(m_modelName))
        || (clientProfile->modelNumber().compare(m_modelNumber))
        || (clientProfile->iconMimeType().compare(m_iconMimeType))
        || (clientProfile->iconWidth() != m_iconWidth)
        || (clientProfile->iconHeight() != m_iconHeight)
        || (clientProfile->iconDepth() != m_iconDepth)
        || (clientProfile->bdAddr().compare(m_bdAddr))
        || (clientProfile->startBTConnection() != m_startBTConnection)
        || (clientProfile->clientRules().getRule(0).compare("true"))
        || (clientProfile->clientRules().getRule(1).compare("test")))
    {
        equal = false;
    }
    else
    {
        equal = true;
    }
    return equal;
}

void QTmClientProfile::setRule(int ruleId, QString ruleValue)
{
    m_clientRules.setRule(ruleId,ruleValue);
}
