/*******************************************************************************
**
** Copyright 2012 Sony Corporation
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Lesser General Public
** License, version 2.1, as published by the Free Software Foundation.
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
** Lesser General Public License for more details.
** You should have received a copy of the GNU Lesser General Public
** License along with this library; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
**
*******************************************************************************/

#ifndef TCPSOCKET_H_
#define TCPSOCKET_H_

 #include <QByteArray>

#define ERR_INVALID_TYPE -10
#define ERR_INVALID_STATE -20

#define PARAM_MAX_BACKLOG 10

enum SocketState
{
	PRE_INIT, CREATED, CONNECTED, CLOSED
};

enum SocketReadState
{
        STOPPED, WAITING, READING
};

enum SocketType
{
	UNDEFINED,CLIENT,SERVER
};

/**
This class handles the TCP socket creation, connection, read, write and error if any.
*/
class TCPSocket
{
private:
	int m_tcp_socket;
    SocketState m_State;

    SocketReadState m_readState;
    fd_set readSet;
    int m_pipe_fds[2];

    void closePipe();
public:
	TCPSocket();
	virtual ~TCPSocket();
    int connectToHost(const char* host, int port);
    int connectToIp(const char* hostIp, int port);
	int socketWrite(void* data, int len);
	int socketRead(void* data, int len);
    int socketReadOnce(QByteArray& rdata, int *rdLen);
	inline SocketState getState(){return (m_State);}
	int closeSocket();
        int forceStopSocketRead();
        int readAll();
};

#endif /* TCPSOCKET_H_ */
