/*******************************************************************************
**
** Copyright 2013 Sony Corporation
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Lesser General Public
** License, version 2.1, as published by the Free Software Foundation.
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
** Lesser General Public License for more details.
** You should have received a copy of the GNU Lesser General Public
** License along with this library; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
**
*******************************************************************************/

#ifndef LIBINTERFACEEMITTER_H
#define LIBINTERFACEEMITTER_H

#include <QtCore/qobject.h>
#include <TmHeaders/libinterface.h>

#define TM_LIBVER_MAJOR     1
#define TM_LIBVER_MINOR     0
#define TM_LIBVER_REVISION  0
#define TM_LIBVER_PURPOSE   0

/**
Structure holding the TM Qt lib version info
*/
typedef struct st_tm_lib_ver
{
   int    major;
   int    minor;
   int    revision;
   int    purpose;
} st_tm_lib_vrsn;


/**
This class is used to ensure that all calls made to TM Qt library are made through signalling mechanism.
When the library is initialized it is expected to create an instance of this class and pass it to LibInterfaceImpl.
The LibInterfaceImpl connects to all the signals emmited by this class.
*/
class LibInterfaceEmitter : public QObject , public LibInterface
{
    Q_OBJECT
public:
    explicit LibInterfaceEmitter(QObject *parent = 0);

    int upnpStartControlPoint();
    int upnpStopControlPoint();
    int upnpConnectControlPoint(char* interfaceName, char* address);

    int upnpDisconnectControlPoint(char* hostAddress);
    int upnpGetApplicationStatus(char*  appId);
    int upnpLaunchApplication(char* appId);
    int upnpTerminateApplication(char* appId);

    int verifyTmClientProfile(QTmClientProfile *clientProfile, int profileId, int serverId);
    int getTmClientProfile(int profileId, int serverId);
    int setTmClientProfile(QTmClientProfile *clientProfile, int profileId, int serverId);

    int vncStartClient();
    int vncConnectClient(char* appId, int clientId);
    int vncDisconnectClient(int clientId);
    int vncStopClient(int clientId);
    int vncSetColorFormat(int colorFormat, int clientId);
    int vncSetRunLengthEncoding(bool enable, int clientId);
    int vncSetIncrementalUpdate(bool enable, int clientId);
    int vncSetPreferredSize(int width, int height, bool scaling, int clientid, double clientSinglePixelWidth, double clientSinglePixelHeight, bool considerPixelComp);
    int vncOnFBReadComplete(int bufferId);
    int vncClickVirtualKey(int clientId, int keySym);
    int vncPointerEvent(int clientId, int x, int y, unsigned int pressed);
    int vncSupportedKeyEvents(int clientId, int knobKey, int deviceKey, int mediaKey);
    int vncKeyEvent(int clientId, int keyId, bool pressed);
    int vncBlockFramebuffer(int x, int y, int width, int height, int appId, int reason, int id);
    int vncResetFbUpdateRequestTimer();
    int vncPauseFbUpdateRequest();
    int vncResumeFbUpdateRequest();
    st_tm_lib_vrsn getTmLibVerInfo();
    /** ------------------------------------------------------------------------------------------- **/

signals:
    void sig_upnpStartControlPoint();
    void sig_upnpConnectControlPoint(char* interfaceName, char* address);
    void sig_upnpStopControlPoint();
    void sig_upnpDisconnectControlPoint(char* hostAddress);
    void sig_upnpGetApplicationStatus(char*  appId);
    //void sig_upnpLaunchApplication(char* appId);
    void sig_upnpLaunchApplication(const QString appId);
    void sig_upnpTerminateApplication(char* appId);

    void sig_verifyTmClientProfile(QTmClientProfile *clientProfile, int profileId, int serverId);
    void sig_getTmClientProfile(int profileId, int serverId);
    void sig_setTmClientProfile(QTmClientProfile *clientProfile, int profileId, int serverId);

    void sig_vncStartClient();
    void sig_vncConnectClient(char* appId, int clientId);
    void sig_vncDisconnectClient(int clientId);
    void sig_vncStopClient(int clientId);
    void sig_vncSetColorFormat(int colorFormat, int clientId);
    void sig_vncSetRunLengthEncoding(bool enable, int clientId);
    void sig_vncSetIncrementalUpdate(bool enable, int clientId);
    void sig_vncSetPreferredSize(int width, int height, bool scaling, int clientid, double clientSinglePixelWidth, double clientSinglePixelHeight, bool considerPixelComp);
    void sig_vncOnFBReadComplete(int bufferId);
    void sig_vncClickVirtualKey(int clientId, int keySym);
    void sig_vncPointerEvent(int clientId, int x, int y, unsigned int pressed);
    void sig_vncSupportedKeyEvents(int clientId, int knobKey, int deviceKey, int mediaKey);
    void sig_vncKeyEvent(int clientId, int keyId, bool pressed);
    void sig_vncBlockFramebuffer(int x, int y, int width, int height, int appId, int reason, int id);
    void sig_vncResetFbUpdateRequestTimer();
    void sig_vncPauseFbUpdateRequest();
    void sig_vncResumeFbUpdateRequest();

    /** ------------------------------------------------------------------------------------------- **/

public slots:

private :

};

#endif // LIBINTERFACEEMITTER_H
